package App::httpstatus;
use strict;
use warnings;
use 5.008005;
our $VERSION = '0.0.1';
1;
__END__

=head1 NAME

App::httpstatus - httpstatus

=head1 LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.
